==> huaweicloudsdkvpcep-3.1.21-py2.py3-none-any.whl: huaweicloudsdkvpcep/v1/model/__init__.py <==
# coding: utf-8

from __future__ import absolute_import

# import models into model package
from huaweicloudsdkvpcep.v1.model.accept_or_reject_endpoint_request import AcceptOrRejectEndpointRequest
from huaweicloudsdkvpcep.v1.model.accept_or_reject_endpoint_request_body import AcceptOrRejectEndpointRequestBody
from huaweicloudsdkvpcep.v1.model.accept_or_reject_endpoint_response import AcceptOrRejectEndpointResponse
from huaweicloudsdkvpcep.v1.model.add_or_remove_service_permissions_request import AddOrRemoveServicePermissionsRequest
from huaweicloudsdkvpcep.v1.model.add_or_remove_service_permissions_request_body import AddOrRemoveServicePermissionsRequestBody
from huaweicloudsdkvpcep.v1.model.add_or_remove_service_permissions_response import AddOrRemoveServicePermissionsResponse
from huaweicloudsdkvpcep.v1.model.batch_add_endpoint_service_permissions_request import BatchAddEndpointServicePermissionsRequest
from huaweicloudsdkvpcep.v1.model.batch_add_endpoint_service_permissions_response import BatchAddEndpointServicePermissionsResponse
from huaweicloudsdkvpcep.v1.model.batch_add_or_remove_resource_instance_body import BatchAddOrRemoveResourceInstanceBody
from huaweicloudsdkvpcep.v1.model.batch_add_or_remove_resource_instance_request import BatchAddOrRemoveResourceInstanceRequest
from huaweicloudsdkvpcep.v1.model.batch_add_or_remove_resource_instance_response import BatchAddOrRemoveResourceInstanceResponse
from huaweicloudsdkvpcep.v1.model.batch_add_permission_request import BatchAddPermissionRequest
from huaweicloudsdkvpcep.v1.model.batch_remove_endpoint_service_permissions_request import BatchRemoveEndpointServicePermissionsRequest
from huaweicloudsdkvpcep.v1.model.batch_remove_endpoint_service_permissions_response import BatchRemoveEndpointServicePermissionsResponse
from huaweicloudsdkvpcep.v1.model.batch_remove_permission_request import BatchRemovePermissionRequest
from huaweicloudsdkvpcep.v1.model.connection_endpoints import ConnectionEndpoints
from huaweicloudsdkvpcep.v1.model.connections_desc import ConnectionsDesc
from huaweicloudsdkvpcep.v1.model.create_endpoint_request import CreateEndpointRequest
from huaweicloudsdkvpcep.v1.model.create_endpoint_request_body import CreateEndpointRequestBody
from huaweicloudsdkvpcep.v1.model.create_endpoint_response import CreateEndpointResponse
from huaweicloudsdkvpcep.v1.model.create_endpoint_service_request import CreateEndpointServiceRequest
from huaweicloudsdkvpcep.v1.model.create_endpoint_service_request_body import CreateEndpointServiceRequestBody
from huaweicloudsdkvpcep.v1.model.create_endpoint_service_response import CreateEndpointServiceResponse
from huaweicloudsdkvpcep.v1.model.delete_endpoint_policy_request import DeleteEndpointPolicyRequest
from huaweicloudsdkvpcep.v1.model.delete_endpoint_policy_response import DeleteEndpointPolicyResponse
from huaweicloudsdkvpcep.v1.model.delete_endpoint_request import DeleteEndpointRequest
from huaweicloudsdkvpcep.v1.model.delete_endpoint_response import DeleteEndpointResponse
from huaweicloudsdkvpcep.v1.model.delete_endpoint_service_request import DeleteEndpointServiceRequest
from huaweicloudsdkvpcep.v1.model.delete_endpoint_service_response import DeleteEndpointServiceResponse
from huaweicloudsdkvpcep.v1.model.endpoint_resp import EndpointResp
from huaweicloudsdkvpcep.v1.model.endpoint_service import EndpointService
from huaweicloudsdkvpcep.v1.model.eps_add_permission_request import EpsAddPermissionRequest
from huaweicloudsdkvpcep.v1.model.eps_permission import EpsPermission
from huaweicloudsdkvpcep.v1.model.eps_remove_permission_request import EpsRemovePermissionRequest
from huaweicloudsdkvpcep.v1.model.eps_update_permission_desc import EpsUpdatePermissionDesc
from huaweicloudsdkvpcep.v1.model.error import Error
from huaweicloudsdkvpcep.v1.model.link import Link
from huaweicloudsdkvpcep.v1.model.list_endpoint_info_details_request import ListEndpointInfoDetailsRequest
from huaweicloudsdkvpcep.v1.model.list_endpoint_info_details_response import ListEndpointInfoDetailsResponse
from huaweicloudsdkvpcep.v1.model.list_endpoint_service_request import ListEndpointServiceRequest
from huaweicloudsdkvpcep.v1.model.list_endpoint_service_response import ListEndpointServiceResponse
from huaweicloudsdkvpcep.v1.model.list_endpoints_request import ListEndpointsRequest
from huaweicloudsdkvpcep.v1.model.list_endpoints_response import ListEndpointsResponse
from huaweicloudsdkvpcep.v1.model.list_query_project_resource_tags_request import ListQueryProjectResourceTagsRequest
from huaweicloudsdkvpcep.v1.model.list_query_project_resource_tags_response import ListQueryProjectResourceTagsResponse
from huaweicloudsdkvpcep.v1.model.list_quota_details_request import ListQuotaDetailsRequest
from huaweicloudsdkvpcep.v1.model.list_quota_details_response import ListQuotaDetailsResponse
from huaweicloudsdkvpcep.v1.model.list_resource_instances_request import ListResourceInstancesRequest
from huaweicloudsdkvpcep.v1.model.list_resource_instances_response import ListResourceInstancesResponse
from huaweicloudsdkvpcep.v1.model.list_service_connections_request import ListServiceConnectionsRequest
from huaweicloudsdkvpcep.v1.model.list_service_connections_response import ListServiceConnectionsResponse
from huaweicloudsdkvpcep.v1.model.list_service_describe_details_request import ListServiceDescribeDetailsRequest
from huaweicloudsdkvpcep.v1.model.list_service_describe_details_response import ListServiceDescribeDetailsResponse
from huaweicloudsdkvpcep.v1.model.list_service_details_request import ListServiceDetailsRequest
from huaweicloudsdkvpcep.v1.model.list_service_details_response import ListServiceDetailsResponse
from huaweicloudsdkvpcep.v1.model.list_service_permissions_details_request import ListServicePermissionsDetailsRequest
from huaweicloudsdkvpcep.v1.model.list_service_permissions_details_response import ListServicePermissionsDetailsResponse
from huaweicloudsdkvpcep.v1.model.list_service_public_details_request import ListServicePublicDetailsRequest
from huaweicloudsdkvpcep.v1.model.list_service_public_details_response import ListServicePublicDetailsResponse
from huaweicloudsdkvpcep.v1.model.list_specified_version_details_request import ListSpecifiedVersionDetailsRequest
from huaweicloudsdkvpcep.v1.model.list_specified_version_details_response import ListSpecifiedVersionDetailsResponse
from huaweicloudsdkvpcep.v1.model.list_version_details_request import ListVersionDetailsRequest
from huaweicloudsdkvpcep.v1.model.list_version_details_response import ListVersionDetailsResponse
from huaweicloudsdkvpcep.v1.model.match import Match
from huaweicloudsdkvpcep.v1.model.permission_object import PermissionObject
from huaweicloudsdkvpcep.v1.model.policy_statement import PolicyStatement
from huaweicloudsdkvpcep.v1.model.port_list import PortList
from huaweicloudsdkvpcep.v1.model.query_error import QueryError
from huaweicloudsdkvpcep.v1.model.query_resource_instance_tags_body import QueryResourceInstanceTagsBody
from huaweicloudsdkvpcep.v1.model.quotas import Quotas
from huaweicloudsdkvpcep.v1.model.resource_instance import ResourceInstance
from huaweicloudsdkvpcep.v1.model.resource_tag import ResourceTag
from huaweicloudsdkvpcep.v1.model.resources_resp import ResourcesResp
from huaweicloudsdkvpcep.v1.model.routetable_info_error import RoutetableInfoError
from huaweicloudsdkvpcep.v1.model.routetable_info_error_detial import RoutetableInfoErrorDetial
from huaweicloudsdkvpcep.v1.model.service_list import ServiceList
from huaweicloudsdkvpcep.v1.model.tag_list import TagList
from huaweicloudsdkvpcep.v1.model.tag_values_list import TagValuesList
from huaweicloudsdkvpcep.v1.model.update_endpoint_connections_desc_request import UpdateEndpointConnectionsDescRequest
from huaweicloudsdkvpcep.v1.model.update_endpoint_connections_desc_response import UpdateEndpointConnectionsDescResponse
from huaweicloudsdkvpcep.v1.model.update_endpoint_policy_request import UpdateEndpointPolicyRequest
from huaweicloudsdkvpcep.v1.model.update_endpoint_policy_request_body import UpdateEndpointPolicyRequestBody
from huaweicloudsdkvpcep.v1.model.update_endpoint_policy_response import UpdateEndpointPolicyResponse
from huaweicloudsdkvpcep.v1.model.update_endpoint_routetable_request import UpdateEndpointRoutetableRequest
from huaweicloudsdkvpcep.v1.model.update_endpoint_routetable_request_body import UpdateEndpointRoutetableRequestBody
from huaweicloudsdkvpcep.v1.model.update_endpoint_routetable_response import UpdateEndpointRoutetableResponse
from huaweicloudsdkvpcep.v1.model.update_endpoint_service_name_mode import UpdateEndpointServiceNameMode
from huaweicloudsdkvpcep.v1.model.update_endpoint_service_name_request import UpdateEndpointServiceNameRequest
from huaweicloudsdkvpcep.v1.model.update_endpoint_service_name_response import UpdateEndpointServiceNameResponse
from huaweicloudsdkvpcep.v1.model.update_endpoint_service_permission_desc_request import UpdateEndpointServicePermissionDescRequest
from huaweicloudsdkvpcep.v1.model.update_endpoint_service_permission_desc_response import UpdateEndpointServicePermissionDescResponse
from huaweicloudsdkvpcep.v1.model.update_endpoint_service_request import UpdateEndpointServiceRequest
from huaweicloudsdkvpcep.v1.model.update_endpoint_service_request_body import UpdateEndpointServiceRequestBody
from huaweicloudsdkvpcep.v1.model.update_endpoint_service_response import UpdateEndpointServiceResponse
from huaweicloudsdkvpcep.v1.model.update_endpoint_white_request import UpdateEndpointWhiteRequest
from huaweicloudsdkvpcep.v1.model.update_endpoint_white_request_body import UpdateEndpointWhiteRequestBody
from huaweicloudsdkvpcep.v1.model.update_endpoint_white_response import UpdateEndpointWhiteResponse
from huaweicloudsdkvpcep.v1.model.update_ep_connections import UpdateEpConnections
from huaweicloudsdkvpcep.v1.model.update_permission_desc_request import UpdatePermissionDescRequest
from huaweicloudsdkvpcep.v1.model.version_object import VersionObject

==> huaweicloudsdkvpcep-3.1.107-py2.py3-none-any.whl: huaweicloudsdkvpcep/v1/model/__init__.py <==
# coding: utf-8

from __future__ import absolute_import

# import models into model package
from huaweicloudsdkvpcep.v1.model.accept_or_reject_endpoint_request import AcceptOrRejectEndpointRequest
from huaweicloudsdkvpcep.v1.model.accept_or_reject_endpoint_request_body import AcceptOrRejectEndpointRequestBody
from huaweicloudsdkvpcep.v1.model.accept_or_reject_endpoint_response import AcceptOrRejectEndpointResponse
from huaweicloudsdkvpcep.v1.model.add_or_remove_service_permissions_request import AddOrRemoveServicePermissionsRequest
from huaweicloudsdkvpcep.v1.model.add_or_remove_service_permissions_request_body import AddOrRemoveServicePermissionsRequestBody
from huaweicloudsdkvpcep.v1.model.add_or_remove_service_permissions_response import AddOrRemoveServicePermissionsResponse
from huaweicloudsdkvpcep.v1.model.batch_add_endpoint_service_permissions_request import BatchAddEndpointServicePermissionsRequest
from huaweicloudsdkvpcep.v1.model.batch_add_endpoint_service_permissions_request_body import BatchAddEndpointServicePermissionsRequestBody
from huaweicloudsdkvpcep.v1.model.batch_add_endpoint_service_permissions_response import BatchAddEndpointServicePermissionsResponse
from huaweicloudsdkvpcep.v1.model.batch_add_or_remove_resource_instance_request import BatchAddOrRemoveResourceInstanceRequest
from huaweicloudsdkvpcep.v1.model.batch_add_or_remove_resource_instance_request_body import BatchAddOrRemoveResourceInstanceRequestBody
from huaweicloudsdkvpcep.v1.model.batch_add_or_remove_resource_instance_response import BatchAddOrRemoveResourceInstanceResponse
from huaweicloudsdkvpcep.v1.model.batch_remove_endpoint_service_permissions_request import BatchRemoveEndpointServicePermissionsRequest
from huaweicloudsdkvpcep.v1.model.batch_remove_endpoint_service_permissions_request_body import BatchRemoveEndpointServicePermissionsRequestBody
from huaweicloudsdkvpcep.v1.model.batch_remove_endpoint_service_permissions_response import BatchRemoveEndpointServicePermissionsResponse
from huaweicloudsdkvpcep.v1.model.connection_endpoints import ConnectionEndpoints
from huaweicloudsdkvpcep.v1.model.connections_desc import ConnectionsDesc
from huaweicloudsdkvpcep.v1.model.create_endpoint_request import CreateEndpointRequest
from huaweicloudsdkvpcep.v1.model.create_endpoint_request_body import CreateEndpointRequestBody
from huaweicloudsdkvpcep.v1.model.create_endpoint_response import CreateEndpointResponse
from huaweicloudsdkvpcep.v1.model.create_endpoint_service_request import CreateEndpointServiceRequest
from huaweicloudsdkvpcep.v1.model.create_endpoint_service_request_body import CreateEndpointServiceRequestBody
from huaweicloudsdkvpcep.v1.model.create_endpoint_service_response import CreateEndpointServiceResponse
from huaweicloudsdkvpcep.v1.model.delete_endpoint_policy_request import DeleteEndpointPolicyRequest
from huaweicloudsdkvpcep.v1.model.delete_endpoint_policy_response import DeleteEndpointPolicyResponse
from huaweicloudsdkvpcep.v1.model.delete_endpoint_request import DeleteEndpointRequest
from huaweicloudsdkvpcep.v1.model.delete_endpoint_response import DeleteEndpointResponse
from huaweicloudsdkvpcep.v1.model.delete_endpoint_service_request import DeleteEndpointServiceRequest
from huaweicloudsdkvpcep.v1.model.delete_endpoint_service_response import DeleteEndpointServiceResponse
from huaweicloudsdkvpcep.v1.model.endpoint_response_body import EndpointResponseBody
from huaweicloudsdkvpcep.v1.model.endpoint_service import EndpointService
from huaweicloudsdkvpcep.v1.model.eps_add_permission_request import EpsAddPermissionRequest
from huaweicloudsdkvpcep.v1.model.eps_permission import EpsPermission
from huaweicloudsdkvpcep.v1.model.eps_remove_permission_request import EpsRemovePermissionRequest
from huaweicloudsdkvpcep.v1.model.eps_update_permission_desc import EpsUpdatePermissionDesc
from huaweicloudsdkvpcep.v1.model.error import Error
from huaweicloudsdkvpcep.v1.model.link import Link
from huaweicloudsdkvpcep.v1.model.list_endpoint_info_details_request import ListEndpointInfoDetailsRequest
from huaweicloudsdkvpcep.v1.model.list_endpoint_info_details_response import ListEndpointInfoDetailsResponse
from huaweicloudsdkvpcep.v1.model.list_endpoint_service_request import ListEndpointServiceRequest
from huaweicloudsdkvpcep.v1.model.list_endpoint_service_response import ListEndpointServiceResponse
from huaweicloudsdkvpcep.v1.model.list_endpoints_request import ListEndpointsRequest
from huaweicloudsdkvpcep.v1.model.list_endpoints_response import ListEndpointsResponse
from huaweicloudsdkvpcep.v1.model.list_query_project_resource_tags_request import ListQueryProjectResourceTagsRequest
from huaweicloudsdkvpcep.v1.model.list_query_project_resource_tags_response import ListQueryProjectResourceTagsResponse
from huaweicloudsdkvpcep.v1.model.list_quota_details_request import ListQuotaDetailsRequest
from huaweicloudsdkvpcep.v1.model.list_quota_details_response import ListQuotaDetailsResponse
from huaweicloudsdkvpcep.v1.model.list_resource_instances_request import ListResourceInstancesRequest
from huaweicloudsdkvpcep.v1.model.list_resource_instances_response import ListResourceInstancesResponse
from huaweicloudsdkvpcep.v1.model.list_service_connections_request import ListServiceConnectionsRequest
from huaweicloudsdkvpcep.v1.model.list_service_connections_response import ListServiceConnectionsResponse
from huaweicloudsdkvpcep.v1.model.list_service_describe_details_request import ListServiceDescribeDetailsRequest
from huaweicloudsdkvpcep.v1.model.list_service_describe_details_response import ListServiceDescribeDetailsResponse
from huaweicloudsdkvpcep.v1.model.list_service_details_request import ListServiceDetailsRequest
from huaweicloudsdkvpcep.v1.model.list_service_details_response import ListServiceDetailsResponse
from huaweicloudsdkvpcep.v1.model.list_service_permissions_details_request import ListServicePermissionsDetailsRequest
from huaweicloudsdkvpcep.v1.model.list_service_permissions_details_response import ListServicePermissionsDetailsResponse
from huaweicloudsdkvpcep.v1.model.list_service_public_details_request import ListServicePublicDetailsRequest
from huaweicloudsdkvpcep.v1.model.list_service_public_details_response import ListServicePublicDetailsResponse
from huaweicloudsdkvpcep.v1.model.list_specified_version_details_request import ListSpecifiedVersionDetailsRequest
from huaweicloudsdkvpcep.v1.model.list_specified_version_details_response import ListSpecifiedVersionDetailsResponse
from huaweicloudsdkvpcep.v1.model.list_version_details_request import ListVersionDetailsRequest
from huaweicloudsdkvpcep.v1.model.list_version_details_response import ListVersionDetailsResponse
from huaweicloudsdkvpcep.v1.model.match import Match
from huaweicloudsdkvpcep.v1.model.permission_object import PermissionObject
from huaweicloudsdkvpcep.v1.model.policy_statement import PolicyStatement
from huaweicloudsdkvpcep.v1.model.port_list import PortList
from huaweicloudsdkvpcep.v1.model.query_error import QueryError
from huaweicloudsdkvpcep.v1.model.query_resource_instance_tags_body import QueryResourceInstanceTagsBody
from huaweicloudsdkvpcep.v1.model.quotas import Quotas
from huaweicloudsdkvpcep.v1.model.resource_instance import ResourceInstance
from huaweicloudsdkvpcep.v1.model.resource_tag import ResourceTag
from huaweicloudsdkvpcep.v1.model.resources_response_body import ResourcesResponseBody
from huaweicloudsdkvpcep.v1.model.routetable_info_error import RoutetableInfoError
from huaweicloudsdkvpcep.v1.model.routetable_info_error_detial import RoutetableInfoErrorDetial
from huaweicloudsdkvpcep.v1.model.service_list import ServiceList
from huaweicloudsdkvpcep.v1.model.tag_list import TagList
from huaweicloudsdkvpcep.v1.model.tag_values_list import TagValuesList
from huaweicloudsdkvpcep.v1.model.update_endpoint_connections_desc_request import UpdateEndpointConnectionsDescRequest
from huaweicloudsdkvpcep.v1.model.update_endpoint_connections_desc_request_body import UpdateEndpointConnectionsDescRequestBody
from huaweicloudsdkvpcep.v1.model.update_endpoint_connections_desc_response import UpdateEndpointConnectionsDescResponse
from huaweicloudsdkvpcep.v1.model.update_endpoint_policy_request import UpdateEndpointPolicyRequest
from huaweicloudsdkvpcep.v1.model.update_endpoint_policy_request_body import UpdateEndpointPolicyRequestBody
from huaweicloudsdkvpcep.v1.model.update_endpoint_policy_response import UpdateEndpointPolicyResponse
from huaweicloudsdkvpcep.v1.model.update_endpoint_routetable_request import UpdateEndpointRoutetableRequest
from huaweicloudsdkvpcep.v1.model.update_endpoint_routetable_request_body import UpdateEndpointRoutetableRequestBody
from huaweicloudsdkvpcep.v1.model.update_endpoint_routetable_response import UpdateEndpointRoutetableResponse
from huaweicloudsdkvpcep.v1.model.update_endpoint_service_name_request import UpdateEndpointServiceNameRequest
from huaweicloudsdkvpcep.v1.model.update_endpoint_service_name_request_body import UpdateEndpointServiceNameRequestBody
from huaweicloudsdkvpcep.v1.model.update_endpoint_service_name_response import UpdateEndpointServiceNameResponse
from huaweicloudsdkvpcep.v1.model.update_endpoint_service_permission_desc_request import UpdateEndpointServicePermissionDescRequest
from huaweicloudsdkvpcep.v1.model.update_endpoint_service_permission_desc_request_body import UpdateEndpointServicePermissionDescRequestBody
from huaweicloudsdkvpcep.v1.model.update_endpoint_service_permission_desc_response import UpdateEndpointServicePermissionDescResponse
from huaweicloudsdkvpcep.v1.model.update_endpoint_service_request import UpdateEndpointServiceRequest
from huaweicloudsdkvpcep.v1.model.update_endpoint_service_request_body import UpdateEndpointServiceRequestBody
from huaweicloudsdkvpcep.v1.model.update_endpoint_service_response import UpdateEndpointServiceResponse
from huaweicloudsdkvpcep.v1.model.update_endpoint_white_request import UpdateEndpointWhiteRequest
from huaweicloudsdkvpcep.v1.model.update_endpoint_white_request_body import UpdateEndpointWhiteRequestBody
from huaweicloudsdkvpcep.v1.model.update_endpoint_white_response import UpdateEndpointWhiteResponse
from huaweicloudsdkvpcep.v1.model.version_object import VersionObject
